Creates a comment in a discussion thread by ID
Deletes a comment in a discussion thread by comment ID
Retrieves a comment from a discussion thread by comment ID
Updates a comment in a discussion thread by comment ID
Creates a workspace data source
Delete a data source
Get the data source’s details
Get all workspace data sources
Update a data source
Creates a new event
Deletes a event
Get a list of all events matching the query
Delete a file from a notebook
Get a file from a notebook
upload a file
Adds rows to the front matter of a notebook.
If the requested position is out of bounds or is not specified, will append the rows to the existing front matter.
Deletes all front matter data for notebook.
If you wish to delete a single key instead of the whole object, use the patch endpoint with value: null
Deletes a row of the front matter for a notebook.
Updates front matter for a given notebook
Updates a front matter row of a given notebook
Get a list of all integrations and their status
Retrieve all label keys
Retrieve all label values
Log out of Fiberplane
Append the given text and optional formatting to the specified cell
Replace some text and formatting in the specified cell
Append the given cells to the notebook. Any cells that have their ID missing will be set on the server.
Convert the notebook cells to a snippet
Downloads the specified notebooks as a Jsonnet template.
Create a new notebook
Deletes a notebook
Creates a copy of the specified notebook
Retrieves a single notebook (both its metadata and content)
Retrieves all Notebooks available to the workspace
Search for notebooks
Expand the snippet and insert the cells into the notebook
Modifies individual properties of a single notebook
List of all available providers and if they’re linked to the current user
Start the auth flow for linking an existing Fiberplane account with a new OID identity (used only with the Studio).
For authenticating with the API see the Authentication section in the docs
Start the auth flow to authenticate a user (used only with the Studio).
For authenticating with the API see the Authentication section in the docs
Pins a notebook
Unpins a notebook
List all pinned notebooks for a specific workspace
Add an existing view to the pinned views list
Remove view from the pinned views list
Get all pinned views for the current user
Fetch the profile of the authenticated user
Retrieve profile image
Upload profile image
Relay a query to call ‘get_config_schema’ from a provider on a remote proxy
Create a new proxy
Relay a query to call ‘create_cells’ from a provider on a remote proxy
Deletes a single proxy
Relay a query to call ‘extract_data’ from a provider on a remote proxy
Retrieve a single proxy
Relays a query to invoke a provider on a remote proxy
List all proxies
Relays a query to invoke a provider on a remote proxy
Relay a query to call ‘get_supported_query_types’ from a provider on a remote proxy
Create a new snippet
Deletes a specified snippet from a workspace
Expand the snippet and return the array of cells (without inserting them into a specific notebook)
Retrieves a specified snippet from a workspace
List the snippets that have been uploaded
Updates a specified snippet from a workspace
Create a new template
Deletes a specified template
Expand the template into a notebook
Retrieves a specified template
Retrieve all the templates that have been uploaded
Updates a specified template
Creates a new comment thread in a notebook
Deletes a discussion thread by ID
Retrieves a discussion thread by ID
Reopens a discussion thread by ID
Resolves a discussion thread by ID
List the threads in the given notebook
Creates a new token
Deletes a token
Retrieves a list of all API tokens
Creates a new trigger for a template
Deletes a trigger from a workspace by its ID
Retrieves a trigger from a workspace by its ID
Invoke a trigger to create a notebook from the associated template
List all created triggers in the workspace
Deletes an existing view
Retrieves a single view
Updates an existing view
Creates a new view
Retrieves all views
Create a new webhook. Upon execution of this route, a test event (“ping”) will be sent to the endpoint.
If sending the ping event fails, the webhook will still be created, but it will be disabled.
Please check the response of this endpoint to see whenever enabled = false,
and if that is the case, check the latest delivery to see why. Once the endpoint has been fixed, you
can re-deliver the ping payload and if that works, manually re-enable the webhook again.
Deletes an existing webhook
Retrieve information about a specific delivery for a specific webhook
Retrieve a list of deliveries for a specific webhook
Resend a specific delivery
Updates an existing webhook. Upon execution of this route, a test event (“ping”) will be sent to the endpoint.
If sending the ping event fails, the webhook will still be updated, but will be disabled.
Please check the response of this endpoint to see whenever enabled = false, and if that is the case
(and not manually requested), check the latest delivery to see why. Once the endpoint has been fixed, you
can re-deliver the ping payload and if that works, manually re-enable the webhook again.
Retrieve all webhooks for a specific workspace
Creates a new workspace
Permanently deletes a specified workspace
Retrieve a front matter schema defined in the workspace
Retrieve all front matter schemas defined in the workspace
Retrieve a front matter schema defined in the workspace
Get the workspace details
Invites a user to a workspace
Accepts the workspace invitation
Declines the workspace invitation
Deletes a pending workspace invitation
Retrieves a list of pending workspace invitations
Leaves a workspace
List all workspaces authenticated user has access to
Retrieves a workspace image
Uploads a workspace image
Update workspace settings
Removes a user from the workspace
Updates the user within a workspace
List all users for a workspace