pub async fn notebook_cell_replace_text(
client: &ApiClient,
notebook_id: Base64Uuid,
cell_id: &str,
payload: CellReplaceText
) -> Result<Cell>Expand description
Replace some text and formatting in the specified cell
pub async fn notebook_cell_replace_text(
client: &ApiClient,
notebook_id: Base64Uuid,
cell_id: &str,
payload: CellReplaceText
) -> Result<Cell>Replace some text and formatting in the specified cell