Function fiberplane_api_client::trigger_get
source · pub async fn trigger_get(
client: &ApiClient,
trigger_id: Base64Uuid
) -> Result<Trigger>Expand description
Retrieves a trigger from a workspace by its ID
pub async fn trigger_get(
client: &ApiClient,
trigger_id: Base64Uuid
) -> Result<Trigger>Retrieves a trigger from a workspace by its ID