pub async fn webhook_update(
    client: &ApiClient,
    workspace_id: Base64Uuid,
    webhook_id: Base64Uuid,
    payload: UpdateWebhook
) -> Result<Webhook>
Updates an existing webhook. Upon execution of this route, a test event (“ping”) will be sent to the endpoint. If sending the ping event fails, the webhook will still be updated, but will be disabled. Please check the response of this endpoint to see whenever enabled = false, and if that is the case (and not manually requested), check the latest delivery to see why. Once the endpoint has been fixed, you can re-deliver the ping payload and if that works, manually re-enable the webhook again.