Function fiberplane_api_client::webhook_create
source · pub async fn webhook_create(
client: &ApiClient,
workspace_id: Base64Uuid,
payload: NewWebhook
) -> Result<Webhook>Expand description
Create a new webhook. Upon execution of this route, a test event (“ping”) will be sent to the endpoint.
If sending the ping event fails, the webhook will still be created, but it will be disabled.
Please check the response of this endpoint to see whenever enabled = false,
and if that is the case, check the latest delivery to see why. Once the endpoint has been fixed, you
can re-deliver the ping payload and if that works, manually re-enable the webhook again.